@@ -28,22 +28,22 @@ _SCHEMA_JSON = {
         "child": {
             "name": "child",
             "schema": "public",
-            "targetKey": ["id"],
+            "targetKey": ["child.id"],
         },
         "parent": {
-            "dep": "child",
-            "depJoin": "parent.id = child.parent_id",
+            "join": "child",
+            "joinOn": "parent.id = child.parent_id",
             "name": "parent",
             "schema": "public",
         },
     },
-    "target": {
+    "targetTable": {
         "key": ["id"],
         "columns": ["id", "parent_name"],
         "name": "child_full",
         "schema": "public",
     },
-    "query": """
+    "targetQuery": """
         SELECT c.id, p.name
         FROM $1 AS d
             JOIN child c ON d.id = c.id
